## Methodology

### Prism Country Methodology
1. If a company is incorporated in, has its headquarters in, and trades on a standard exchange in the same country (excluding ADRs and ADSs), the company is assigned to its country of incorporation. If any of these three criteria do not align, three country factors are defined:
   - Country of incorporation
   - Country of headquarters
   - Country of the most liquid exchange, determined by the two-year average daily dollar trading volume (ADDTV) from all exchanges within the country.

2. After defining these factors, the next step in country assignment involves analyzing the company's assets by location. The primary location of the company’s assets is compared with the three country factors. If the primary asset location matches any of the three factors, the company is assigned to that location.

3. If there is insufficient information to determine a company’s primary asset location, the primary location of the company’s revenue is used for the same cross-comparison, and the company is assigned to the appropriate country in a similar manner.

4. If conclusive country details cannot be derived from assets or revenue, the company is assigned to its headquarters country unless that country is a Benefit Driven Incorporation (BDI) country. If the headquarters country is a BDI, the company is assigned to the country of its most liquid stock exchange.

   BDI Countries:
   - Anguilla, Liechtenstein, Antigua and Barbuda, Gibraltar, Guernsey, Isle of Man, Jersey, Liberia, Marshall Islands, Panama

5. Companies designated as Chinese “N Shares” are not considered. An N Share is a company incorporated outside of mainland China that trades on the New York Stock Exchange, the NASDAQ Exchange, or the NYSE American. An N Share has its headquarters or principal executive office in mainland China and derives the majority of its revenue or assets from the PRC.


### Prism Primary Methodology
The primary listing for a company is determined based on the liquidity of its listings. The most liquid listing is identified by the two-year average daily dollar trading volume (ADDTV). If there is oscillation between multiple listings across different time periods within a company, the "sandwiched" listing (where the older and newer listings are the same and the middle listing is different) is removed, based on the previously established primary listing.